==> spqr-0.10.0-sources.jar: io/leangen/graphql/util/Urls.java <==
package io.leangen.graphql.util;

public final class Urls {

    public static final String ISSUES = "https://github.com/leangen/graphql-spqr/issues";

    public static final class Errors {
        public static final String DERIVED_TYPES = "https://github.com/leangen/graphql-spqr/wiki/Errors#derived-types";
        public static final String DYNAMIC_PROXIES = "https://github.com/leangen/graphql-spqr/wiki/Errors#dynamic-proxies";
        public static final String TOP_LEVEL_GENERICS = "https://github.com/leangen/graphql-spqr/wiki/Errors#generic-top-level-singletons";
        public static final String NON_UNIQUE_TYPE_NAME = "https://github.com/leangen/graphql-spqr/wiki/Errors#non-unique-type-name";
        public static final String CONFLICTING_RESOLVER_TYPES = "https://github.com/leangen/graphql-spqr/wiki/Errors#operation-with-multiple-resolver-methods-of-different-types";
        public static final String MISSING_ARGUMENT_NAME = "https://github.com/leangen/graphql-spqr/wiki/Errors#missing-argument-name";
        public static final String AMBIGUOUS_MEMBER_TYPE = "https://github.com/leangen/graphql-spqr/wiki/Errors#ambiguous-member-type";
        public static final String AMBIGUOUS_PARAMETER_TYPE = "https://github.com/leangen/graphql-spqr/wiki/Errors#ambiguous-method-parameter-type";
        public static final String RELAY_CONNECTION_SPEC_VIOLATION = "https://github.com/leangen/graphql-spqr/wiki/Errors#relay-connection-spec-violation";
        public static final String IMPLEMENTATION_CLASS_LOADING_FAILED = "https://github.com/leangen/graphql-spqr/wiki/Errors#class-loading-issues";
    }
}

==> spqr-0.12.3-sources.jar: io/leangen/graphql/util/Urls.java <==
package io.leangen.graphql.util;

public final class Urls {

    public static final String ISSUES = "https://github.com/leangen/graphql-spqr/issues";

    public static final class Errors {
        public static final String DERIVED_TYPES = "https://github.com/leangen/graphql-spqr/wiki/Errors#derived-types";
        public static final String DYNAMIC_PROXIES = "https://github.com/leangen/graphql-spqr/wiki/Errors#dynamic-proxies";
        public static final String TOP_LEVEL_GENERICS = "https://github.com/leangen/graphql-spqr/wiki/Errors#generic-top-level-singletons";
        public static final String NON_UNIQUE_TYPE_NAME = "https://github.com/leangen/graphql-spqr/wiki/Errors#non-unique-type-name";
        public static final String CONFLICTING_RESOLVER_TYPES = "https://github.com/leangen/graphql-spqr/wiki/Errors#operation-with-multiple-resolver-methods-of-different-types";
        public static final String MISSING_ARGUMENT_NAME = "https://github.com/leangen/graphql-spqr/wiki/Errors#missing-argument-name";
        public static final String UNRESOLVABLE_SUPER_TYPE = "https://github.com/leangen/graphql-spqr/wiki/Errors#unresolvable-super-type";
        public static final String AMBIGUOUS_MEMBER_TYPE = "https://github.com/leangen/graphql-spqr/wiki/Errors#ambiguous-member-type";
        public static final String AMBIGUOUS_PARAMETER_TYPE = "https://github.com/leangen/graphql-spqr/wiki/Errors#ambiguous-method-parameter-type";
        public static final String RELAY_CONNECTION_SPEC_VIOLATION = "https://github.com/leangen/graphql-spqr/wiki/Errors#relay-connection-spec-violation";
        public static final String IMPLEMENTATION_CLASS_LOADING_FAILED = "https://github.com/leangen/graphql-spqr/wiki/Errors#class-loading-issues";
    }
}
